* + minmax-deduplicate-__unconst_integer_typeof.patch added to mm-nonmm-unstable branch
@ 2023-09-11 18:25 Andrew Morton
2023-09-11 21:47 ` Andy Shevchenko
0 siblings, 1 reply; 4+ messages in thread
From: Andrew Morton @ 2023-09-11 18:25 UTC (permalink / raw)
To: mm-commits, herve.codina, andriy.shevchenko, akpm
The patch titled
Subject: minmax: deduplicate __unconst_integer_typeof()
has been added to the -mm mm-nonmm-unstable branch. Its filename is
minmax-deduplicate-__unconst_integer_typeof.patch
This patch will shortly appear at
https://git.kernel.org/pub/scm/linux/kernel/git/akpm/25-new.git/tree/patches/minmax-deduplicate-__unconst_integer_typeof.patch
This patch will later appear in the mm-nonmm-unstable branch at
git://git.kernel.org/pub/scm/linux/kernel/git/akpm/mm
Before you just go and hit "reply", please:
a) Consider who else should be cc'ed
b) Prefer to cc a suitable mailing list as well
c) Ideally: find the original patch on the mailing list and do a
reply-to-all to that, adding suitable additional cc's
*** Remember to use Documentation/process/submit-checklist.rst when testing your code ***
The -mm tree is included into linux-next via the mm-everything
branch at git://git.kernel.org/pub/scm/linux/kernel/git/akpm/mm
and is updated there every 2-3 working days
------------------------------------------------------
From: Andy Shevchenko <andriy.shevchenko@linux.intel.com>
Subject: minmax: deduplicate __unconst_integer_typeof()
Date: Mon, 11 Sep 2023 18:49:13 +0300
It appears that compiler_types.h already have an implementation of the
__unconst_integer_typeof() called __unqual_scalar_typeof(). Use it
instead of the copy.
Link: https://lkml.kernel.org/r/20230911154913.4176033-1-andriy.shevchenko@linux.intel.com
Signed-off-by: Andy Shevchenko <andriy.shevchenko@linux.intel.com>
Acked-by: Herve Codina <herve.codina@bootlin.com>
Signed-off-by: Andrew Morton <akpm@linux-foundation.org>
---
include/linux/minmax.h | 26 +++-----------------------
1 file changed, 3 insertions(+), 23 deletions(-)
--- a/include/linux/minmax.h~minmax-deduplicate-__unconst_integer_typeof
+++ a/include/linux/minmax.h
@@ -2,6 +2,7 @@
#ifndef _LINUX_MINMAX_H
#define _LINUX_MINMAX_H
+#include <linux/compiler_types.h>
#include <linux/const.h>
#include <linux/types.h>
@@ -135,27 +136,6 @@
#define max_t(type, x, y) __careful_cmp((type)(x), (type)(y), >)
/*
- * Remove a const qualifier from integer types
- * _Generic(foo, type-name: association, ..., default: association) performs a
- * comparison against the foo type (not the qualified type).
- * Do not use the const keyword in the type-name as it will not match the
- * unqualified type of foo.
- */
-#define __unconst_integer_type_cases(type) \
- unsigned type: (unsigned type)0, \
- signed type: (signed type)0
-
-#define __unconst_integer_typeof(x) typeof( \
- _Generic((x), \
- char: (char)0, \
- __unconst_integer_type_cases(char), \
- __unconst_integer_type_cases(short), \
- __unconst_integer_type_cases(int), \
- __unconst_integer_type_cases(long), \
- __unconst_integer_type_cases(long long), \
- default: (x)))
-
-/*
* Do not check the array parameter using __must_be_array().
* In the following legit use-case where the "array" passed is a simple pointer,
* __must_be_array() will return a failure.
@@ -169,13 +149,13 @@
* 'int *buff' and 'int buff[N]' types.
*
* The array can be an array of const items.
* typeof() keeps the const qualifier. Use __unconst_integer_typeof() in order
* to discard the const qualifier for the __element variable.
*/
#define __minmax_array(op, array, len) ({ \
typeof(&(array)[0]) __array = (array); \
typeof(len) __len = (len); \
- __unconst_integer_typeof(__array[0]) __element = __array[--__len]; \
+ __unqual_scalar_typeof(__array[0]) __element = __array[--__len];\
while (__len--) \
__element = op(__element, __array[__len]); \
__element; })
_
Patches currently in -mm which might be from andriy.shevchenko@linux.intel.com are
minmax-deduplicate-__unconst_integer_typeof.patch
^ permalink raw reply [flat|nested] 4+ messages in thread
* Re: + minmax-deduplicate-__unconst_integer_typeof.patch added to mm-nonmm-unstable branch
2023-09-11 18:25 + minmax-deduplicate-__unconst_integer_typeof.patch added to mm-nonmm-unstable branch Andrew Morton
@ 2023-09-11 21:47 ` Andy Shevchenko
2023-09-11 21:59 ` Andrew Morton
0 siblings, 1 reply; 4+ messages in thread
From: Andy Shevchenko @ 2023-09-11 21:47 UTC (permalink / raw)
To: Andrew Morton; +Cc: mm-commits, herve.codina
On Mon, Sep 11, 2023 at 11:25:56AM -0700, Andrew Morton wrote:
>
> The patch titled
> Subject: minmax: deduplicate __unconst_integer_typeof()
> has been added to the -mm mm-nonmm-unstable branch. Its filename is
> minmax-deduplicate-__unconst_integer_typeof.patch
>
> This patch will shortly appear at
> https://git.kernel.org/pub/scm/linux/kernel/git/akpm/25-new.git/tree/patches/minmax-deduplicate-__unconst_integer_typeof.patch
>
> This patch will later appear in the mm-nonmm-unstable branch at
> git://git.kernel.org/pub/scm/linux/kernel/git/akpm/mm
>
> Before you just go and hit "reply", please:
> a) Consider who else should be cc'ed
> b) Prefer to cc a suitable mailing list as well
> c) Ideally: find the original patch on the mailing list and do a
> reply-to-all to that, adding suitable additional cc's
>
> *** Remember to use Documentation/process/submit-checklist.rst when testing your code ***
>
> The -mm tree is included into linux-next via the mm-everything
> branch at git://git.kernel.org/pub/scm/linux/kernel/git/akpm/mm
> and is updated there every 2-3 working days
...
> /*
> -/*
> * Do not check the array parameter using __must_be_array().
> * In the following legit use-case where the "array" passed is a simple pointer,
> * __must_be_array() will return a failure.
A side note: If you look at the original email and patch you will see a subtle
difference that makes patch better looking. It's because I started using
--patience when formatting them. Perhaps you can enable it in your scripts.
@@ -169,13 +149,13 @@
*
* The array can be an array of const items.
- * typeof() keeps the const qualifier. Use __unconst_integer_typeof() in order
+ * typeof() keeps the const qualifier. Use __unqual_scalar_typeof() in order
* to discard the const qualifier for the __element variable.
*/
--
With Best Regards,
Andy Shevchenko
^ permalink raw reply [flat|nested] 4+ messages in thread
* Re: + minmax-deduplicate-__unconst_integer_typeof.patch added to mm-nonmm-unstable branch
2023-09-11 21:47 ` Andy Shevchenko
@ 2023-09-11 21:59 ` Andrew Morton
2023-09-11 22:23 ` Andy Shevchenko
0 siblings, 1 reply; 4+ messages in thread
From: Andrew Morton @ 2023-09-11 21:59 UTC (permalink / raw)
To: Andy Shevchenko; +Cc: mm-commits, herve.codina
On Tue, 12 Sep 2023 00:47:43 +0300 Andy Shevchenko <andriy.shevchenko@linux.intel.com> wrote:
> > -/*
> > * Do not check the array parameter using __must_be_array().
> > * In the following legit use-case where the "array" passed is a simple pointer,
> > * __must_be_array() will return a failure.
>
> A side note: If you look at the original email and patch you will see a subtle
> difference that makes patch better looking. It's because I started using
> --patience when formatting them. Perhaps you can enable it in your scripts.
Interesting, thanks.
I use plain old diff :(. A while back I had everything working (I
thought) using `git diff' instead but found that it was producing diffs that
gave git-quiltimport a heart attack. Ran out of time, didn't debug,
disabled it. I'll revisit at some point.
^ permalink raw reply [flat|nested] 4+ messages in thread
* Re: + minmax-deduplicate-__unconst_integer_typeof.patch added to mm-nonmm-unstable branch
2023-09-11 21:59 ` Andrew Morton
@ 2023-09-11 22:23 ` Andy Shevchenko
0 siblings, 0 replies; 4+ messages in thread
From: Andy Shevchenko @ 2023-09-11 22:23 UTC (permalink / raw)
To: Andrew Morton; +Cc: mm-commits, herve.codina
On Mon, Sep 11, 2023 at 02:59:56PM -0700, Andrew Morton wrote:
> On Tue, 12 Sep 2023 00:47:43 +0300 Andy Shevchenko <andriy.shevchenko@linux.intel.com> wrote:
...
> > > -/*
> > > * Do not check the array parameter using __must_be_array().
> > > * In the following legit use-case where the "array" passed is a simple pointer,
> > > * __must_be_array() will return a failure.
> >
> > A side note: If you look at the original email and patch you will see a subtle
> > difference that makes patch better looking. It's because I started using
> > --patience when formatting them. Perhaps you can enable it in your scripts.
>
> Interesting, thanks.
>
> I use plain old diff :(. A while back I had everything working (I
> thought) using `git diff' instead but found that it was producing diffs that
> gave git-quiltimport a heart attack. Ran out of time, didn't debug,
> disabled it. I'll revisit at some point.
Ah, I see. I don't know good implementation of patience diff outside of
the Git, not sure then if you can enable it easily.
--
With Best Regards,
Andy Shevchenko
^ permalink raw reply [flat|nested] 4+ messages in thread
end of thread, other threads:[~2023-09-12 3:08 UTC | newest]
Thread overview: 4+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2023-09-11 18:25 + minmax-deduplicate-__unconst_integer_typeof.patch added to mm-nonmm-unstable branch Andrew Morton
2023-09-11 21:47 ` Andy Shevchenko
2023-09-11 21:59 ` Andrew Morton
2023-09-11 22:23 ` Andy Shevchenko
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.